// $Id: DummyMidiInDevice.cc 8352 2008-11-12 18:39:08Z m9710797 $

#include "DummyMidiInDevice.hh"

namespace openmsx {

void DummyMidiInDevice::signal(EmuTime::param /*time*/)
{
	// ignore
}

const std::string& DummyMidiInDevice::getDescription() const
{
	static const std::string EMPTY;
	return EMPTY;
}

void DummyMidiInDevice::plugHelper(Connector& /*connector*/,
                                   EmuTime::param /*time*/)
{
}

void DummyMidiInDevice::unplugHelper(EmuTime::param /*time*/)
{
}

} // namespace openmsx
